import { defineNuxtModule, createResolver, addPlugin, addImportsDir } from '@nuxt/kit';

const module = defineNuxtModule({
  meta: {
    name: "@nuxtjs/snipcart",
    configKey: "snipcart",
    compatibility: {
      nuxt: "^3.0.0"
    }
  },
  defaults: {
    version: "3.0",
    publicApiKey: "",
    timeoutDuration: 2750,
    domain: "cdn.snipcart.com",
    protocol: "https",
    loadCSS: true,
    loadStrategy: "",
    addProductBehavior: "",
    modalStyle: "",
    language: "en",
    templatesUrl: "",
    currency: "usd",
    subscription: false,
    translations: {}
  },
  async setup(options, nuxt) {
    if (!options.publicApiKey.length) {
      throw new Error("publicApiKey cant be null");
    }
    nuxt.options.runtimeConfig.public.snipcart = options;
    const resolver = createResolver(import.meta.url);
    addPlugin(resolver.resolve("./runtime/plugin"));
    addImportsDir(resolver.resolve("./runtime/composables"));
  }
});

export { module as default };
